-- استيراد الفئات اللازمة من AndroLua
require "import"
import "android.app.Service"
import "android.content.Context"
import "android.hardware.Sensor"
import "android.hardware.SensorEvent"
import "android.hardware.SensorEventListener"
import "android.hardware.SensorManager"
import "android.util.Log"
import "android.widget.*"
import "android.widget.LinearLayout"
import "android.widget.TextView"
import "android.view.View"

-- إنشاء فئة Lua لخدمة مستشعر الضوء
local LightSensorService = {}

-- تهيئة مدير المستشعر والمستشعر كمتغيرات فرعية
local sensorManager
local lightSensor

-- إنشاء مستمع حدث المستشعر
local sensorEventListener = luajava.createProxy("android.hardware.SensorEventListener", {
    onAccuracyChanged = function(sensor, accuracy) end,
    onSensorChanged = function(event)
        if event.sensor.getType() == Sensor.TYPE_LIGHT then
            local lightValue = event.values[0]  -- استخدام event.values[0] لقياس شدة الضوء
            -- التعامل مع بيانات شدة الضوء حسب الحاجة (على سبيل المثال، عرضها أو تخزينها)
            updateLightIntensity(lightValue)
            -- طباعة شدة الضوء إلى سجل Android
            Log.d("خدمة مستشعر الضوء", "شدة الضوء: " .. lightValue)
        end
    end
})

-- تعريف متغير عالمي لعرض شدة الضوء
local lightIntensityTextView
local serviceRunning = false  -- علم لتتبع حالة الخدمة

-- مُنشئ لفئة خدمة مستشعر الضوء
function LightSensorService:new(context)
    local obj = {}
    setmetatable(obj, self)
    self.__index = self

    -- تهيئة مدير المستشعر والحصول على مستشعر الضوء
    sensorManager = context.getSystemService(Context.SENSOR_SERVICE)
    lightSensor = sensorManager.getDefaultSensor(Sensor.TYPE_LIGHT)

    return obj
end

-- التحقق مما إذا كان مستشعر الضوء متاحًا
function LightSensorService:isLightSensorAvailable()
    return lightSensor ~= nil
end

-- استبدال الأساليب اللازمة للخدمة
function LightSensorService:onCreate()
    -- تسجيل مستمع الحدث عند إنشاء الخدمة
    sensorManager.registerListener(sensorEventListener, lightSensor, SensorManager.SENSOR_DELAY_NORMAL)
    serviceRunning = true  -- الخدمة قيد التشغيل
end

function LightSensorService:onDestroy()
    -- إلغاء تسجيل مستمع الحدث عند تدمير الخدمة
    sensorManager.unregisterListener(sensorEventListener)
    serviceRunning = false  -- توقفت الخدمة
    updateLightIntensity(nil)  -- مسح عرض شدة الضوء

-- إعادة فئة LightSensorService
return LightSensorService
end

local context
local service

local layout = LinearLayout(activity)
layout.setOrientation(LinearLayout.VERTICAL)

local startButton = Button(activity)
startButton.setText("بدء الخدمة")
local stopButton  -- تعريف stopButton هنا
startButton.setOnClickListener(View.OnClickListener {
    onClick = function(view)
        if not serviceRunning then
            -- التحقق مما إذا كان مستشعر الضوء متاحًا
            context = activity
            service = LightSensorService:new(context)
            if service:isLightSensorAvailable() then
                service:onCreate()
                startButton.setEnabled(false)
                stopButton.setEnabled(true)
            else
                -- التعامل مع الحالة عند عدم توفر المستشعر على الجهاز
                -- يمكنك عرض رسالة أو اتخاذ إجراء مناسب هنا
                showToast("مستشعر الضوء غير متاح على هذا الجهاز.")
            end
        end
    end
})
layout.addView(startButton)

stopButton = Button(activity)  -- تهيئة stopButton هنا
stopButton.setText("إيقاف الخدمة")
stopButton.setEnabled(false)
stopButton.setOnClickListener(View.OnClickListener {
    onClick = function(view)
        if serviceRunning then
            -- إيقاف الخدمة
            service:onDestroy()
            startButton.setEnabled(true)
            stopButton.setEnabled(false)
            -- عرض "تم إيقاف الخدمة" في نص العرض
            lightIntensityTextView.setText("تم إيقاف الخدمة")
        end
    end
})
layout.addView(stopButton)

lightIntensityTextView = TextView(activity)  -- إزالة "محلي" لتعريفها كمتغير عالمي
lightIntensityTextView.setText("الإضاءة المحيطة: غ/م²")
layout.addView(lightIntensityTextView)

-- تعيين تخطيط النشاط
activity.setContentView(layout)

-- دالة لتحديث وصف شدة الضوء
function updateLightIntensity(lightValue)
    activity.runOnUiThread(Runnable {
        run = function()
            if lightValue then
                local description = ""

                -- تحديد الوصف استنادًا إلى شدة الضوء
                if lightValue < 5 then
                    description = "المكان مظلم جدًا"
                elseif lightValue < 20 then
                    description = "المكان مظلم"
                elseif lightValue < 50 then
                    description = "المكان ضعيف الإضاءة"
                elseif lightValue < 100 then
                    description = "المكان متوسط الإضاءة"
                elseif lightValue < 200 then
                    description = "المكان مشرق"
                elseif lightValue < 400 then
                    description = "المكان مضيء"
                elseif lightValue < 600 then
                    description = "المكان جدًا مضيء"
                else
                    description = "المكان شديد الإضاءة"
                end

                lightIntensityTextView.setText("الإضاءة المحيطة: " .. math.floor(lightValue) .. " (" .. description .. ")")
            else
                lightIntensityTextView.setText("تم إيقاف الخدمة")
            end
        end
    })
end

-- دالة لعرض رسالة توست
function showToast(message)
    activity.runOnUiThread(Runnable {
        run = function()
            local toast = Toast.makeText(activity, message, Toast.LENGTH_SHORT)
            toast.show()
        end
    })
end
